Features
--------

The table below lists the notable features for messlidger.
Refer to `xmpp.org <https://xmpp.org/software/slidge/>`_ for a longer version,
including all XEPs supported by `slidge <https://slidge.im/>`_.

.. doap:: ../../doap.xml
